==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/language/1/barnraiser_01/sch_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//SECTION
$lang['section_schedule_item'] = 					"schedule";


//HEADER
$lang['hdr_author'] = 								"author";
$lang['hdr_schedule_event'] = 						"event";
$lang['hdr_schedule_task'] = 						"task";
$lang['hdr_detail'] = 								"details";
$lang['hdr_attendance'] = 							"attendance";


//LINKS
$lang['href_event_withdraw_confirmation'] = 		"withdraw from this event";
$lang['href_edit_attendance'] = 					"edit attendance";
$lang['href_edit_this'] = 							"edit this";
$lang['href_event_apply'] = 						"apply to attend this event";
$lang['href_goto_group'] = 							"goto group to edit";


//BODY TEXT
$lang['txt_bc_schedule'] = 							"schedule"; // breadcrumb
$lang['txt_event_apply'] = 							"apply to attend this event.";
$lang['txt_event_apply_update'] = 					"reapply for this schedule item";
$lang['txt_event_full'] = 							"Sorry. this event has all the required participants.";
$lang['txt_event_withdraw_confirmation'] =			"If you no longer wish to participate you can withdraw. Please remember to inform the schedule organiser why.";
$lang['txt_allocation'] = 							"allocation";
$lang['txt_applications'] = 						"applications";
$lang['txt_confirmed'] = 							"confirmed";
$lang['txt_end'] = 									"end";
$lang['txt_location'] = 							"location";
$lang['txt_start'] = 								"start";
$lang['txt_status'] = 								"status";
$lang['txt_profile_create_datetime'] = 				"joined";
$lang['txt_profile_hometown'] = 					"home town";
$lang['txt_profile_nic'] = 							"nickname";
$lang['txt_profile_session_status'] = 				"status";
$lang['txt_event_allocation_intro'] = 				"You can attend this event. You can withdraw from an event at any time.";
$lang['txt_allocation_full'] = 						"sorry, there are no places left";
$lang['txt_priority'] = 							"priority";
$lang['txt_complete'] = 							"completed";
$lang['txt_p_complete'] = 							"percentage complete";
$lang['txt_no_start'] = 							"no start date";
$lang['txt_no_end'] = 								"no end date";
$lang['txt_all_day_item'] = 						"all day item";
$lang['txt_application'] = 							"attendance application";
$lang['txt_application_rejected'] = 				"Your application to attend this event was rejected by the event author. If you have your default profile set to allow messaging you should have received a message from the organiser explaining their decision. If you are not happy then contact the community administrator.";
$lang['txt_published_to'] = 						"Published to";
$lang['txt_group_title'] = 							"Group title";
$lang['txt_group_language'] = 						"language";
$lang['txt_group_type'] = 							"type";
$lang['txt_rec_age'] = 								"age";
$lang['txt_age_all'] = 								"all";
$lang['txt_age_from'] = 							"from";
$lang['txt_age_upto'] = 							"upto";
$lang['txt_hidden'] = 								"hidden";

//$lang['section_schedule'] = 						"my schedule";
//$lang['hdr_task_allocated'] = 						"allocated tasks";
//$lang['hdr_task_initiated'] = 						"initiated tasks";
//$lang['hdr_event_attendance'] = 					"event attendance";
//$lang['hdr_event_initiated'] = 						"initiated events";
//FORM
//$lang['form_label_from_date'] = 					"starting date [mm-dd-yyyy]";
//$lang['form_label_show'] = 							"number of days shown";
//$lang['form_option_all'] = 							"all";
//$lang['form_label_title'] = 						"title";
//$lang['form_label_synopsis'] = 						"synopsis";
//$lang['href_recommend_this'] = 						"tip this";
//$lang['href_unrecommend_this'] =					"remove tip";
//$lang['href_unwatch_this'] =						"remove mark";
//$lang['href_watch_this'] =							"add mark";
//$lang['href_event_add'] = 							"add event";
//$lang['href_task_add'] = 							"add task";
//$lang['txt_profile_nic'] = 							"nic";
//ERRORS
//$lang['err_no_tasks'] = 							"Sorry, there are no tasks available in the schedule.";

?>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/sch_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//SECTION
$lang['section_schedule_item'] = 					"schedule";
$lang['section_add_comment'] = 						"add comment";
$lang['section_comments'] = 						"comments";


//HEADER
$lang['hdr_author'] = 								"author";
$lang['hdr_schedule_event'] = 						"event";
$lang['hdr_schedule_task'] = 						"task";
$lang['hdr_detail'] = 								"details";
$lang['hdr_attendance'] = 							"attendance";
$lang['hdr_comment_preview'] = 						"comment preview";
$lang['hdr_tag'] = 									"tags";


// SUB
$lang['sub_edit_again'] = 							"edit again";
$lang['sub_save'] = 								"save";
$lang['sub_update_tag'] = 							"update my tags";
$lang['sub_preview'] = 								"preview";
$lang['sub_add'] = 									"add";


// ERR
$lang['err_no_comments'] = 							"Sorry, there are no comments available.";


//LINKS
$lang['href_event_withdraw_confirmation'] = 		"withdraw from this event";
$lang['href_edit_attendance'] = 					"edit attendance";
$lang['href_edit_this'] = 							"edit this";
$lang['href_event_apply'] = 						"apply to attend this event";
$lang['href_goto_group'] = 							"goto group to edit";
$lang['href_comments'] = 							"comments";


//BODY TEXT
$lang['txt_bc_schedule'] = 							"schedule"; // breadcrumb
$lang['txt_event_apply'] = 							"apply to attend this event.";
$lang['txt_event_apply_update'] = 					"reapply for this schedule item";
$lang['txt_event_full'] = 							"Sorry. this event has all the required participants.";
$lang['txt_event_withdraw_confirmation'] =			"If you no longer wish to participate you can withdraw. Please remember to inform the schedule organiser why.";
$lang['txt_allocation'] = 							"allocation";
$lang['txt_applications'] = 						"applications";
$lang['txt_confirmed'] = 							"confirmed";
$lang['txt_end'] = 									"end";
$lang['txt_location'] = 							"location";
$lang['txt_start'] = 								"start";
$lang['txt_status'] = 								"status";
$lang['txt_profile_create_datetime'] = 				"joined";
$lang['txt_profile_hometown'] = 					"home town";
$lang['txt_profile_nic'] = 							"nickname";
$lang['txt_profile_session_status'] = 				"status";
$lang['txt_event_allocation_intro'] = 				"You can attend this event. You can withdraw from an event at any time.";
$lang['txt_allocation_full'] = 						"sorry, there are no places left";
$lang['txt_priority'] = 							"priority";
$lang['txt_complete'] = 							"completed";
$lang['txt_p_complete'] = 							"percentage complete";
$lang['txt_no_start'] = 							"no start date";
$lang['txt_no_end'] = 								"no end date";
$lang['txt_all_day_item'] = 						"all day item";
$lang['txt_application'] = 							"attendance application";
$lang['txt_application_rejected'] = 				"Your application to attend this event was rejected by the event author. If you have your default profile set to allow messaging you should have received a message from the organiser explaining their decision. If you are not happy then contact the community administrator.";
$lang['txt_published_to'] = 						"Published to";
$lang['txt_group_title'] = 							"Group title";
$lang['txt_group_language'] = 						"language";
$lang['txt_group_type'] = 							"type";
$lang['txt_rec_age'] = 								"age";
$lang['txt_age_all'] = 								"all";
$lang['txt_age_from'] = 							"from";
$lang['txt_age_upto'] = 							"upto";
$lang['txt_hidden'] = 								"hidden";
$lang['txt_check_spelling'] =						"Check Spelling";
$lang['txt_no_comment_allowed'] = 					"Sorry, this shedule item is not open to receive your comments.";
$lang['txt_tag_intro'] = 							"This shedule item has been tagged with";
$lang['txt_tag_network'] = 							"My network have tagged this shedule item with";
$lang['txt_tag_group'] = 							"This group has tagged this shedule item with";
$lang['txt_comment_help'] = 						"Remember to observe the rules of the group. Reply in group language only.";
$lang['txt_from'] = 								"from";
$lang['txt_non_member'] = 							"NON MEMBER";
$lang['txt_joined'] = 								"Joined";
$lang['txt_hometown'] = 							"Hometown";

?>
